-- Custom Variable Declaration


-- Private Variable Declaration
local stats = 
	{
	{"health", STAT_HEALTH_MAX},
	{"stamina", STAT_STAMINA_MAX},
	{"magicka", STAT_MAGICKA_MAX},
	{"health regen", STAT_HEALTH_REGEN_COMBAT},
	{"stamina regen", STAT_STAMINA_REGEN_COMBAT},
	{"magicka regen", STAT_MAGICKA_REGEN_COMBAT},
	{"spell damage", STAT_SPELL_POWER},
	{"weapon damage", STAT_WEAPON_POWER},
	{"spell resistance", STAT_SPELL_RESIST},
	{"armor", STAT_ARMOR_RATING}
	}


-- Functions
function OverchargeInfo_overcharge(extra) -- /overcharge
	extra = string.lower(extra)
	
	if (extra == "help" or extra == "?" or extra == "") -- Check if player wants help
	then
		CHAT_SYSTEM:AddMessage("Supported Stats:")
		for i = 1, #stats, 1 -- Iterate through all supported stats
		do
			CHAT_SYSTEM:AddMessage("-- " .. string.lower(stats[i][1]))
		end
	else
		OverchargeInfo_stat(extra) -- Otherwise, try to display a stat's overcharge amount
	end
end

function OverchargeInfo_stat(requestedStat) -- Player did not ask for help; assume player specified a stat
	local foundStat = nil
	for i = 1, #stats, 1 -- Iterate through all supported stats
	do
		if (requestedStat == string.lower(stats[i][1]))
		then
			foundStat = i
			break
		end
	end
	
	if foundStat -- If the requested stat was found, calculate overcharge amount for the requested stat
	then
		local actual = nil
		local uncapped = nil
		local wasted = nil
		local percent = nil
		
		-- Get stat information
		actual = GetPlayerStat(stats[foundStat][2], STAT_BONUS_OPTION_APPLY_BONUS, STAT_SOFT_CAP_OPTION_APPLY_SOFT_CAP)
		uncapped = GetPlayerStat(stats[foundStat][2], STAT_BONUS_OPTION_APPLY_BONUS, STAT_SOFT_CAP_OPTION_DONT_APPLY_SOFT_CAP)
		
		wasted = uncapped - actual
		
		if (uncapped ~= 0)
		then
			percent = round((wasted / uncapped)*100, 1)
		else
			percent = 0
		end
		
		-- If stat information was calculated successfully
		if (actual ~= nil and uncapped ~= nil and wasted ~= nil)
		then
			CHAT_SYSTEM:AddMessage("Lost " .. stats[foundStat][1] .. ": " .. tostring(wasted) .. "  (" .. tostring(percent) .. "%)")
		else
			CHAT_SYSTEM:AddMessage("Error: There was a problem while retrieving the overcharge amount.")
		end
	else
		CHAT_SYSTEM:AddMessage("That stat is not supported!")
		CHAT_SYSTEM:AddMessage("Type '/overcharge' to see a list of supported stats.")
	end
end

function round(num, idp) -- Simple rounding function
	local mult = 10^(idp or 0)
	return math.floor(num * mult + 0.5) / mult
end


-- Initilize Slash Commands
SLASH_COMMANDS["/overcharge"] = OverchargeInfo_overcharge
SLASH_COMMANDS["/oc"] = OverchargeInfo_overcharge